package org.example.sweater.controller;

import org.example.sweater.config.TelegramBotProperties;
import org.example.sweater.domain.User;
import org.example.sweater.service.UserService;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.Map;

@Controller
public class AuthorizationController {
    public AuthorizationController(UserService usersRepository, TelegramBotProperties telegramBotProperties) {
        this.userService = usersRepository;
        this.telegramProperties = telegramBotProperties;
    }

    private final UserService userService;
    private final TelegramBotProperties telegramProperties;

    @GetMapping("/login")
    public String login() {
        return "login";
    }

    @GetMapping("/activation")
    public String activation(
            String key,
            Model model
    ) {
        String link = "https://t.me/" + telegramProperties.getName() + "?start=" + key;

        model.addAttribute("link", link);
        return "activation";
    }

    @GetMapping("/registration")
    public String registration() {
        return "registration";
    }

    @PostMapping("/registration")
    public String addUser(User user, Map<String, Object> model) {
        boolean isAdded = userService.addUser(user);

        if (!isAdded) {
            model.put("message", "User exists!");
            return "registration";
        }

        return "redirect:/activation?key=" + user.getTelegramActivationCode();
    }
}
