package org.example.sweater.service;

import org.example.sweater.config.TelegramBotProperties;
import org.example.sweater.domain.Role;
import org.example.sweater.domain.User;
import org.example.sweater.repos.UsersRepository;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.UUID;

@Service
public class UserService implements UserDetailsService {
    private final UsersRepository usersRepository;
    private final TelegramBotProperties telegramBotProperties;

    public UserService(UsersRepository usersRepository, TelegramBotProperties telegramBotProperties) {
        this.usersRepository = usersRepository;
        this.telegramBotProperties = telegramBotProperties;
    }

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {
        return usersRepository.findByUsername(username);
    }

    public boolean addUser(User user) {
        User userFromStorage = usersRepository.findByUsername(user.getUsername());

        if (userFromStorage != null) {
            return false;
        }

        user.setActive(false);
        user.setRoles(Collections.singleton(Role.USER));
        user.setTelegramActivationCode(UUID.randomUUID().toString());
        usersRepository.save(user);

        String telegramUsername = user.getUsername();

        if (telegramUsername == null || telegramUsername.isEmpty()) {
            return false;
        }

        String message = String.format(
                "Hello, %s! \n Welcome to Sweater. Please, visit next link to activate your account with username %s https://t.me/%s?start=%s",
                user.getUsername(), user.getUsername(), telegramBotProperties.getName(), user.getTelegramActivationCode()
        );
        System.out.println(message);

        return true;
    }
}
